/*Web: http://www.buydisplay.com
EastRising Technology Co.,LTD
Examples for ER-EPD0154-2B
Display is Hardward SPI 4-Wire SPI Interface 
Tested and worked with:
Works with Arduino 1.6.0 IDE  
Works with Arduino DUE,Arduino mega2560,Arduino UNO Board
****************************************************/

#include "ER-EPD0154-2B.h"
#include "GUI_Paint.h"
#include "EPD_SDCard.h"
#include "ImageData.h"
#include <Wire.h>
#include <SPI.h>
#include <SD.h>

void setup()
{
    GUIPAINT paint;
    EPD2IN9 epd;
    EPD_SDCARD SD;
    
    //Initialize e-Paper
    if (epd.EPD_Init() != 0) {
        Serial.print("e-Paper init failed");
        return;
    }
    epd.EPD_Clear();
    Serial.print("1.54inch e-Paper demo\n");

#if 1
    //show sd card pic
    //1.Initialize the SD card
    SD.SDCard_Init();
    
    //2.Create a new image cache named IMAGE_BW and fill it with white
    paint.Paint_NewImage(IMAGE_BW, EPD_WIDTH, EPD_HEIGHT, IMAGE_ROTATE_0, IMAGE_COLOR_INVERTED);
    paint.Paint_Clear(WHITE);    
    
    //3.Read BMP pictures into RAM
    SD.SDCard_ReadBMP("154-2b1.bmp", 0, 0);
    
    //4.Refresh the picture in RAM to e-Paper
    epd.EPD_Display();
    Dev->Dev_Delay_ms(2000);
    
      //2.Create a new image cache named IMAGE_BW and fill it with white
    paint.Paint_NewImage(IMAGE_BW, EPD_WIDTH, EPD_HEIGHT, IMAGE_ROTATE_0, IMAGE_COLOR_POSITIVE);
    paint.Paint_Clear(WHITE);    
    
    //3.Read BMP pictures into RAM
    SD.SDCard_ReadBMP("154-2b2.bmp", 0, 0);
    
    //4.Refresh the picture in RAM to e-Paper
    epd.EPD_Display();
    Dev->Dev_Delay_ms(2000);  
#endif    
    
#if 1
    //show image for array
    //1.Create a new image cache named IMAGE_BW and fill it with white
    paint.Paint_NewImage(IMAGE_BW, EPD_WIDTH, EPD_HEIGHT, IMAGE_ROTATE_0, IMAGE_COLOR_POSITIVE);
    
    //2.show image for array, IMAGE_ROTATE_0 and IMAGE_COLOR_POSITIVE will not affect reading
    paint.Paint_DrawBitMap(IMAGE_DATA);
    
    //3.Refresh the picture in RAM to e-Paper
    epd.EPD_Display();
    Dev->Dev_Delay_ms(2000);
#endif

#if 1
    //1.Create a new image cache named IMAGE_BW and fill it with white
    UBYTE Rotate = IMAGE_ROTATE_270;
    paint.Paint_NewImage(IMAGE_BW, EPD_WIDTH, EPD_HEIGHT, Rotate, IMAGE_COLOR_POSITIVE);
    paint.Paint_Clear(WHITE);
    
    //2.Drawing on the image
    if (Rotate == IMAGE_ROTATE_0 || Rotate == IMAGE_ROTATE_180) {
        Serial.print("Vertical screen\n");
        
        paint.Paint_DrawPoint(10, 20, BLACK, DOT_PIXEL_1X1, DOT_STYLE_DFT);
        paint.Paint_DrawPoint(10, 30, BLACK, DOT_PIXEL_2X2, DOT_STYLE_DFT);
        paint.Paint_DrawPoint(10, 40, BLACK, DOT_PIXEL_3X3, DOT_STYLE_DFT);

        paint.Paint_DrawLine(20, 20, 70, 70, BLACK, LINE_STYLE_SOLID, DOT_PIXEL_1X1);
        paint.Paint_DrawLine(70, 20, 20, 70, BLACK, LINE_STYLE_SOLID, DOT_PIXEL_1X1);
        paint.Paint_DrawLine(10, 90, 40, 90, BLACK, LINE_STYLE_DOTTED, DOT_PIXEL_1X1);
        paint.Paint_DrawLine(25, 105, 25, 75, BLACK, LINE_STYLE_DOTTED, DOT_PIXEL_1X1);

        paint.Paint_DrawRectangle(20, 20, 70, 70, BLACK, DRAW_FILL_EMPTY, DOT_PIXEL_1X1);
    
        paint.Paint_DrawCircle(25, 90, 15, BLACK, DRAW_FILL_EMPTY, DOT_PIXEL_1X1);
        paint.Paint_DrawCircle(60, 90, 15, BLACK, DRAW_FILL_FULL, DOT_PIXEL_1X1);

        paint.Paint_DrawString_EN(10, 120, "hello world", &Font12, WHITE, BLACK);
        paint.Paint_DrawString_EN(10, 140, "EastRising", &Font12, BLACK, WHITE);

        paint.Paint_DrawNum(10, 160, 12345678, &Font12, BLACK, WHITE);
        paint.Paint_DrawNum(10, 180, 98765432, &Font16, WHITE, BLACK);
    } else {
        Serial.print("Horizontal screen\n");
            
        paint.Paint_DrawPoint(10, 80, BLACK, DOT_PIXEL_1X1, DOT_STYLE_DFT);
        paint.Paint_DrawPoint(10, 90, BLACK, DOT_PIXEL_2X2, DOT_STYLE_DFT);
        paint.Paint_DrawPoint(10, 100, BLACK, DOT_PIXEL_3X3, DOT_STYLE_DFT);

        paint.Paint_DrawLine(130, 70, 160, 100, BLACK, LINE_STYLE_SOLID, DOT_PIXEL_1X1);
        paint.Paint_DrawLine(160, 70, 130, 100, BLACK, LINE_STYLE_SOLID, DOT_PIXEL_1X1);
        paint.Paint_DrawLine(45, 85, 75, 85, BLACK, LINE_STYLE_DOTTED, DOT_PIXEL_1X1);
        paint.Paint_DrawLine(60, 70, 60, 100, BLACK, LINE_STYLE_DOTTED, DOT_PIXEL_1X1);

        paint.Paint_DrawRectangle(130, 70, 160, 100, BLACK, DRAW_FILL_EMPTY, DOT_PIXEL_1X1);
        paint.Paint_DrawRectangle(170, 70, 200, 100, BLACK, DRAW_FILL_FULL, DOT_PIXEL_1X1);

        paint.Paint_DrawCircle(60, 85, 15, BLACK, DRAW_FILL_EMPTY, DOT_PIXEL_1X1);
        paint.Paint_DrawCircle(100, 85, 15, BLACK, DRAW_FILL_FULL, DOT_PIXEL_1X1);

        paint.Paint_DrawString_EN(10, 2, "www.buydisplay.com", &Font12, BLACK, WHITE);
        paint.Paint_DrawString_EN(10, 20, "hello world", &Font12, WHITE, BLACK);

        paint.Paint_DrawNum(10, 33, 123456789, &Font12, BLACK, WHITE);
        paint.Paint_DrawNum(10, 50, 987654321, &Font16, WHITE, BLACK);        
    }

    //3.Refresh the picture in RAM to e-Paper
    epd.EPD_Display();
    Dev->Dev_Delay_ms(2000);//Analog clock 1s

#endif

  Dev->Dev_Delay_ms(15000);
   epd.EPD_Clear();
     epd.EPD_TurnOnDisplay(); 
     
    epd.EPD_Sleep();  
}

void loop()
{

}
